@@ -28,6 +28,15 @@ impl Indices for &[usize] {
         else { self.iter().rev().map(|&i| v[i]).collect()   } 
     }
 
+    /// Collects values from v in the order given by self index
+    /// and converts them to f64.  
+    /// When ascending is false, collects in descending order.  
+    /// It is used here by msort for ascending or descending sort.   
+    fn unindexf64<T: Copy>(self, v:&[T], ascending: bool) -> Vec<f64> where f64:From<T> {
+        if ascending { self.iter().map(|&i| f64::from(v[i])).collect() }
+        else { self.iter().rev().map(|&i| f64::from(v[i])).collect()   } 
+    }
+
     /// Complement of an index  (is symmetric) - 
     /// .complindex() toggles rank index between ascending/descending.
     /// `.complindex().invindex()` = .invindex().revindex() 
